@@ -5,15 +5,15 @@
 
 import pybean
 import os
-import eyeD3
 import subprocess
 import re
 import unicodedata
 import shutil
 import datetime
 from hsaudiotag import mp4
+from hsaudiotag import auto
 
-__version__ = "0.0.10"
+__version__ = "0.0.11"
 __author__ = "Mickael Desfrenes"
 __email__ = "desfrenes@gmail.com"
 
@@ -79,23 +79,15 @@ def load_metas_from_mp4(filename, metas_instance):
 
 def load_metas_from_mp3(filename, metas_instance):
     try:
-        trackInfo = eyeD3.Mp3AudioFile(filename)
-        tag = trackInfo.getTag()
-        if tag:
-            tag.link(filename)
-            metas_instance.artist = tag.getArtist()
-            metas_instance.title = tag.getTitle()
-            metas_instance.album = tag.getAlbum()
-            metas_instance.year = tag.getYear()
-            try:
-                genre = tag.getGenre()
-                if genre:
-                    metas_instance.genre = genre.name
-            except eyeD3.GenreException:
-                pass
-            if tag.getComment() is not None:
-                metas_instance.comment = tag.getComment()
-            metas_instance.duration = trackInfo.getPlayTimeString()
+        tags = auto.File(filename)
+        metas_instance.artist = tags.artist
+        metas_instance.title = tags.title
+        metas_instance.album = tags.album
+        metas_instance.year = tags.year
+        metas_instance.genre = tags.genre
+        metas_instance.comment = tags.comment
+        metas_instance.duration = str(
+            datetime.timedelta(seconds=tags.duration))
     except:
         pass
 
